@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -32,6 +32,7 @@ import datetime
 import warnings
 import logging
 
+import six
 from sqlalchemy import orm
 
 from rattail.db import model, api
@@ -177,7 +178,7 @@ class BatchHandler(object):
             batch.data_rows.append(row)
             self.refresh_row(row)
         if not row.removed:
-            batch.rowcount += 1
+            batch.rowcount = (batch.rowcount or 0) + 1
             self.after_add_row(batch, row)
 
     def after_add_row(self, batch, row):
@@ -470,6 +471,31 @@ class BatchHandler(object):
         account for this possibility.
         """
 
+    def refresh_product_basics(self, row):
+        """
+        This method will refresh the "basic" product info for a row.  It
+        assumes that the row is derived from
+        :class:`~rattail.db.model.batch.core.ProductBatchRowMixin` and that
+        ``row.product`` is already set to a valid product.
+        """
+        product = getattr(row, 'product', None)
+        if not product:
+            return
+
+        row.item_id = product.item_id
+        row.upc = product.upc
+        row.brand_name = six.text_type(product.brand or "")
+        row.description = product.description
+        row.size = product.size
+
+        department = product.department
+        row.department_number = department.number if department else None
+        row.department_name = department.name if department else None
+
+        subdepartment = product.subdepartment
+        row.subdepartment_number = subdepartment.number if subdepartment else None
+        row.subdepartment_name = subdepartment.name if subdepartment else None
+
     def quick_entry(self, session, batch, entry):
         """
         Handle a "quick entry" value, e.g. from user input.  Most frequently this
