@@ -437,6 +437,25 @@ class Subcommand(object):
         raise NotImplementedError
 
 
+class CheckDatabase(Subcommand):
+    """
+    Do basic sanity checks on a Rattail DB
+    """
+    name = 'checkdb'
+    description = __doc__.strip()
+
+    def run(self, args):
+        import sqlalchemy as sa
+
+        try:
+            self.config.rattail_engine.execute("select version()")
+        except sa.exc.OperationalError as e:
+            self.stderr.write("\nfailed to connect to DB!\n\n{}\n".format(e))
+            sys.exit(1)
+
+        self.stdout.write("All checks passed.\n")
+
+
 class CloneDatabase(Subcommand):
     """
     Clone (supported) data from a source DB to a target DB
@@ -990,8 +1009,6 @@ class MakeAppDir(Subcommand):
                             "of this option probably requires 'sudo' or equivalent.")
 
     def run(self, args):
-        import pwd
-
         if args.path:
             app_path = os.path.abspath(args.path)
             if os.path.basename(app_path) != 'app':
@@ -1004,8 +1021,9 @@ class MakeAppDir(Subcommand):
             os.mkdir(app_path)
 
         if args.user:
+            import pwd
             pwdata = pwd.getpwnam(args.user)
-        for name in ['batch', 'data', 'log', 'sessions', 'work']:
+        for name in ['data', 'log', 'sessions', 'work']:
             path = os.path.join(app_path, name)
             if not os.path.exists(path):
                 os.mkdir(path)
