@@ -298,6 +298,24 @@ class ImportCSV(ImportFileSubcommand):
         return load_object(spec)
 
 
+class ImportIFPS(ImportFileSubcommand):
+    """
+    Import data from IFPS file(s) to Rattail database
+    """
+    name = 'import-ifps'
+    description = __doc__.strip()
+    default_handler_spec = 'rattail.importing.ifps:FromIFPSToRattail'
+
+    def get_handler_factory(self, **kwargs):
+        if self.config:
+            spec = self.config.get('rattail.importing', 'ifps.handler',
+                                   default=self.default_handler_spec)
+        else:
+            # just use default, for sake of cmd line help
+            spec = self.default_handler_spec
+        return load_object(spec)
+
+
 class ExportFileSubcommand(ImportSubcommand):
     """
     Base class for export commands which target data file(s)
