@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -364,6 +364,24 @@ class RattailConfig(object):
     # convenience methods
     ##############################
 
+    def get_app(self):
+        """
+        Returns the global Rattail ``AppHandler`` instance, creating it first
+        if necessary.
+        """
+        if not hasattr(self, 'app'):
+            from rattail.app import make_app
+            self.app = make_app(self)
+        return self.app
+
+    def app_package(self, default=None):
+        """
+        Returns the name of Python package for the top-level app.
+        """
+        if not default:
+            return self.require('rattail', 'app_package')
+        return self.get('rattail', 'app_package', default=default)
+
     def app_title(self, default=None):
         """
         Returns official display title for the current app.
@@ -715,7 +733,8 @@ def default_system_paths():
         try:
             from win32com.shell import shell, shellcon
         except ImportError:
-            raise WindowsExtensionsNotInstalled
+            # raise WindowsExtensionsNotInstalled
+            return []
         else:
             return [
                 os.path.join(shell.SHGetSpecialFolderPath(
@@ -743,7 +762,8 @@ def default_user_paths():
         try:
             from win32com.shell import shell, shellcon
         except ImportError:
-            raise WindowsExtensionsNotInstalled
+            # raise WindowsExtensionsNotInstalled
+            return []
         else:
             return [
                 os.path.join(shell.SHGetSpecialFolderPath(
