@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,6 +28,7 @@ from __future__ import unicode_literals, absolute_import
 
 import logging
 
+import six
 from sqlalchemy.orm import joinedload
 
 from rattail.core import Object
@@ -53,7 +54,7 @@ class ModelCacher(object):
     def __init__(self, session, model_class, key='uuid',
                  query=None, order_by=None, query_options=None, normalizer=None,
                  expect_duplicates=False, omit_duplicates=False,
-                 use_lists=False):
+                 use_lists=False, message=None):
         self.session = session
         self.model_class = model_class
         self.key = key
@@ -68,6 +69,10 @@ class ModelCacher(object):
         else:
             self.normalize = normalizer
         self.use_lists = use_lists
+
+        self.message = message
+        if not self.message:
+            self.message = "Caching {} data".format(self.model_name)
     
     @property
     def model_name(self):
@@ -91,7 +96,7 @@ class ModelCacher(object):
         
         prog = None
         if progress:
-            prog = progress("Caching {0} data".format(self.model_name), count)
+            prog = progress(self.message, count)
         for i, instance in enumerate(query, 1):
 
             self.cache_instance(instance)
@@ -103,7 +108,8 @@ class ModelCacher(object):
 
         if self.duplicate_keys:
             logger = log.debug if self.expect_duplicates else log.warning
-            logger("found {} duplicated keys in cache".format(len(self.duplicate_keys)))
+            logger("found %s duplicated keys in cache for %s",
+                   len(self.duplicate_keys), self.model_name)
             if self.omit_duplicates:
                 for key in self.duplicate_keys:
                     log.debug("removing duplicated key from cache: {}".format(repr(key)))
@@ -114,7 +120,7 @@ class ModelCacher(object):
     def get_key(self, instance, normalized):
         if callable(self.key):
             return self.key(instance, normalized)
-        if isinstance(self.key, basestring):
+        if isinstance(self.key, six.string_types):
             return getattr(instance, self.key)
         return tuple(getattr(instance, k) for k in self.key)
 
@@ -209,7 +215,7 @@ class CategoryCacher(DataCacher):
     class_ = model.Category
 
     def cache_instance(self, category):
-        self.instances[category.number] = category
+        self.instances[category.code] = category
 
 
 def cache_categories(session, progress=None):
