@@ -115,6 +115,14 @@ class Customer(ContactMixin, Base):
         if self.person:
             return self.person.employee
 
+    def first_person(self):
+        """
+        Convenience method to retrieve the "first" Person record which is
+        associated with this customer, or ``None``.
+        """
+        if self.people:
+            return self.people[0]
+
     def only_person(self):
         """
         Convenience method to retrieve the one and only Person record which is
@@ -126,6 +134,17 @@ class Customer(ContactMixin, Base):
                 len(self.people), self))
         return self.people[0]
 
+    def only_member(self, require=True):
+        """
+        Convenience method to retrieve the one and only Member record which is
+        associated with this customer.  If ``require=True`` then an error will
+        be raised if there is not exactly one member found.
+        """
+        if len(self.members) > 1 or (require and not self.members):
+            raise ValueError("customer {} should have 1 member but instead has {}: {}".format(
+                self.uuid, len(self.members), self))
+        return self.members[0] if self.members else None
+
 
 class CustomerPhoneNumber(PhoneNumber):
     """
@@ -292,6 +311,8 @@ class CustomerPerson(Base):
     __table_args__ = (
         sa.ForeignKeyConstraint(['customer_uuid'], ['customer.uuid'], name='customer_x_person_fk_customer'),
         sa.ForeignKeyConstraint(['person_uuid'], ['person.uuid'], name='customer_x_person_fk_person'),
+        sa.Index('customer_x_person_ix_customer', 'customer_uuid'),
+        sa.Index('customer_x_person_ix_person', 'person_uuid'),
     )
     __versioned__ = {}
 
@@ -302,7 +323,7 @@ class CustomerPerson(Base):
 
     customer = orm.relationship(Customer, back_populates='_people')
 
-    person = orm.relationship(Person, back_populates='_customers')
+    person = orm.relationship(Person)
 
 
 Customer._people = orm.relationship(
@@ -330,7 +351,7 @@ Customer.person = association_proxy(
     getset_factory=getset_factory)
 
 Person._customers = orm.relationship(
-    CustomerPerson, back_populates='person',
+    CustomerPerson,
     primaryjoin=CustomerPerson.person_uuid == Person.uuid,
     viewonly=True)
 
