@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,6 +28,7 @@ from __future__ import unicode_literals, absolute_import
 
 import datetime
 
+import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
@@ -67,8 +68,14 @@ class Message(Base):
     UTC timestamp when the message was sent.
     """)
 
-    def __unicode__(self):
-        return unicode(self.subject or '')
+    def __str__(self):
+        if six.PY2:
+            return (self.subject or '').encode('utf8')
+        return (self.subject or '')
+
+    if six.PY2:
+        def __unicode__(self):
+            return (self.subject or '')
 
     def add_recipient(self, user, **kwargs):
         """
@@ -90,6 +97,7 @@ class Message(Base):
         return False
 
 
+@six.python_2_unicode_compatible
 class MessageRecipient(Base):
     """
     Represents the combination of a single message and a single recipient.
@@ -126,5 +134,5 @@ class MessageRecipient(Base):
         """,
         backref=orm.backref('_messages'))
 
-    def __unicode__(self):
-        return unicode(self.recipient)
+    def __str__(self):
+        return str(self.recipient)
