@@ -111,6 +111,7 @@ class Importer(object):
     def __init__(self, config=None, key=None, direction='import', fields=None, exclude_fields=None, **kwargs):
         self.config = config
         self.enum = config.get_enum() if config else None
+        self.model = config.get_model() if config else None
         self.model_class = kwargs.pop('model_class', self.get_model_class())
         if key is not None:
             self.key = key
@@ -299,7 +300,14 @@ class Importer(object):
                     log.debug("did NOT create new {} for key: {}".format(self.model_name, key))
 
             # flush changes every so often
-            if not self.batch_size or (len(created) + len(updated)) % self.batch_size == 0:
+            flush = False
+            if not self.batch_size or self.batch_size == 1:
+                # flush every time if no meaningful batch size
+                flush = True
+            elif created or updated:
+                if (len(created) + len(updated)) % self.batch_size == 0:
+                    flush = True
+            if flush:
                 self.flush_create_update()
 
         try:
