@@ -26,6 +26,8 @@ Rattail -> Rattail data import
 
 from __future__ import unicode_literals, absolute_import
 
+import logging
+
 import sqlalchemy as sa
 
 from rattail.db import Session
@@ -35,6 +37,9 @@ from rattail.importing.sqlalchemy import FromSQLAlchemySameToSame
 from rattail.util import OrderedDict
 
 
+log = logging.getLogger(__name__)
+
+
 class FromRattailHandler(FromSQLAlchemyHandler):
     """
     Base class for import handlers which target a Rattail database on the local side.
@@ -65,6 +70,19 @@ class ToRattailHandler(ToSQLAlchemyHandler):
 
     def begin_local_transaction(self):
         self.session = self.make_session()
+
+        # load "runas user" into current session
+        if hasattr(self, 'runas_user') and self.runas_user:
+            dbmodel = self.config.get_model()
+            runas_user = self.session.query(dbmodel.User)\
+                                     .get(self.runas_user.uuid)
+            if not runas_user:
+                log.info("runas_user does not exist in target session: %s",
+                         self.runas_user.username)
+            # this may be None if user does not exist in target session
+            self.runas_user = runas_user
+
+        # declare "runas user" is data versioning author
         if hasattr(self, 'runas_username') and self.runas_username:
             self.session.set_continuum_user(self.runas_username)
 
