@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,12 @@
 Handler for Generating Projects
 """
 
+from __future__ import unicode_literals, absolute_import
+
 import os
+import random
 import shutil
+import string
 import subprocess
 import sys
 
@@ -120,9 +124,16 @@ class ProjectHandler(object):
                     locations.append('{}.db:alembic/versions'.format(options['python_name']))
                 options['alembic_version_locations'] = ' '.join(reversed(locations))
 
+            if 'beaker_session_secret' not in options:
+                options['beaker_session_secret'] = self.random_string()
+
         self.do_generate(project_type, slug, options, path)
         return path
 
+    def random_string(self, size=20, chars=string.ascii_letters + string.digits):
+        # per https://stackoverflow.com/a/2257449
+        return ''.join(random.SystemRandom().choice(chars) for _ in range(size))
+
     def do_generate(self, project_type, slug, options, path):
         """
         This method supplies the "true" logic for generating new project code.
@@ -370,6 +381,25 @@ class RattailProjectHandler(ProjectHandler):
             self.generate('rattail/package/web/views/common.py.mako', os.path.join(views, 'common.py'),
                           **context)
 
+        ##############################
+        # dev
+        ##############################
+
+        dev = os.path.join(path, 'dev')
+        os.makedirs(dev)
+
+        self.generate('rattail/dev/bootstrap.py.mako', os.path.join(dev, 'bootstrap.py'),
+                      **context)
+
+        self.generate('rattail/dev/tasks.py.mako', os.path.join(dev, 'tasks.py'),
+                      **context)
+
+        self.generate('rattail/dev/rattail.conf.mako', os.path.join(dev, 'rattail.conf'),
+                      **context)
+
+        self.generate('rattail/dev/web.conf.mako', os.path.join(dev, 'web.conf'),
+                      **context)
+
         ##############################
         # fablib / machines
         ##############################
