@@ -58,27 +58,35 @@ class ExcelReport(Report):
     def make_filename(self, session, params, data, **kwargs):
         return "{}.xlsx".format(self.name)
 
-    def write_file(self, session, params, data, path, progress=None, **kwargs):
+    def make_excel_writer(self, path, **kwargs):
         """
-        Write a basic Excel output file with the given data.  Requires at least
-        the ``output_fields`` attribute to be set to work correctly.
+        Create the Excel writer instance, for the given path.
+        """
+        fields = kwargs.pop('fields', self.output_fields)
+        kwargs.setdefault('number_formats', self.number_formats)
+        kwargs.setdefault('sheet_title', "Report Data")
+        return ExcelWriter(path, fields, **kwargs)
+
+    def write_data_sheet(self, writer, session, params, data,
+                         progress=None, **kwargs):
+        """
+        Write the primary data sheet for the Excel output file.
         """
-        writer = ExcelWriter(path, self.output_fields,
-                             number_formats=self.number_formats)
         writer.write_header()
 
         # convert data to Excel-compatible rows
-        rows = [
+        data_rows = data if isinstance(data, list) else data['rows']
+        xlrows = [
             [row[field] for field in self.output_fields]
-            for row in data]
+            for row in data_rows]
 
         # write main data rows
-        writer.write_rows(rows, progress=progress)
+        writer.write_rows(xlrows, progress=progress)
 
         # maybe add a TOTALS row
         totals = {}
         for field in self.totalled_fields:
-            totals[field] = sum([row[field] for row in data])
+            totals[field] = sum([row[field] for row in data_rows])
         if totals:
 
             # create totals row data
@@ -90,17 +98,53 @@ class ExcelReport(Report):
                     rowdata.append(None)
 
             # append row to output
-            writer.write_row(rowdata, row=len(data) + 2)
+            writer.write_row(rowdata, row=len(data_rows) + 2)
 
             # apply row highlighting
             fill_totals = PatternFill(patternType='solid',
                                       fgColor='ffee88',
                                       bgColor='ffee88')
             for col, field in enumerate(self.output_fields, 1):
-                cell = writer.sheet.cell(row=len(data) + 2, column=col)
+                cell = writer.sheet.cell(row=len(data_rows) + 2, column=col)
                 cell.fill = fill_totals
 
         writer.auto_freeze()
         writer.auto_filter()
         writer.auto_resize()
+
+    def write_summary_sheet(self, writer, session, params, data,
+                            progress=None, **kwargs):
+        """
+        Write the secondary "summary" sheet for the Excel output file.
+        """
+
+        summary = writer.create_sheet("Report Summary")
+
+        summary.append([])
+        summary.append([self.name])
+
+        summary.append([])
+        summary.append(["Parameters:"])
+        for key, value in params.items():
+            summary.append([key, value])
+
+        self.add_more_to_summary(writer, summary, session, params, data)
+
+        writer.disable_grid_lines()
+        writer.auto_resize()
+
+    def add_more_to_summary(self, writer, summary, session, params, data):
+        pass
+
+    def write_file(self, session, params, data, path, progress=None, **kwargs):
+        """
+        Write a basic Excel output file with the given data.  Requires at least
+        the ``output_fields`` attribute to be set to work correctly.
+        """
+        writer = self.make_excel_writer(path)
+
+        self.write_data_sheet(writer, session, params, data, progress=progress)
+
+        self.write_summary_sheet(writer, session, params, data, progress=progress)
+
         writer.save()
